Param
(
[Switch]
$Hash
)

# Copy local modules into the system module directory.
$modulePath = Join-Path $PSScriptRoot -ChildPath 'Modules\*'
$moduleInstallDir = "${env:ProgramFiles}\WindowsPowerShell\Modules"
Copy-Item $modulePath -Destination $moduleInstallDir -Recurse -Force
$installedModules = (Get-ChildItem $modulePath).BaseName

# Enable TLSv1.2
[Net.ServicePointManager]::SecurityProtocol = [Net.SecurityProtocolType]::Tls12

# A minimum version of NuGet is needed to install modules from PSGallery.
Install-PackageProvider -Name NuGet -MinimumVersion 2.8.5.201 -Force | Out-Null

# Ensure PSGallery repository is set and get its settings.
Register-PSRepository -Default -ErrorAction Ignore
$psgallery = Get-PSRepository -Name 'PSGallery'

# Install remote modules via the trusted PSGallery.
Set-PSRepository -Name 'PSGallery' -InstallationPolicy Trusted
Install-Module 'PowerShellGet' -Repository 'PSGallery' -Force
Install-Module 'AuditPolicyDsc' -Repository 'PSGallery' -Force -RequiredVersion 1.4.0.0
Install-Module 'CertificateDsc' -Repository 'PSGallery' -Force -RequiredVersion 4.6.0.0
Install-Module 'SecurityPolicyDsc' -Repository 'PSGallery' -Force -RequiredVersion 2.7.0.0
Install-Module 'xDscDiagnostics' -Repository 'PSGallery' -Force -RequiredVersion 2.7.0.0
$installedModules += $moduleList

# Return the installation policy to PSGallery.
Set-PSRepository -Name 'PSGallery' -InstallationPolicy $psgallery.InstallationPolicy

# Enable more log statuses.
# Disable them first to prevent error about failed activation while active.
Update-xDscEventLogStatus -Channel Analytic -Status Disabled
Update-xDscEventLogStatus -Channel Debug -Status Disabled
Update-xDscEventLogStatus -Channel Analytic -Status Enabled
Update-xDscEventLogStatus -Channel Debug -Status Enabled

# Get file hashes of all installed modules, if needed.
if ($Hash)
{
	$installedModules | Foreach-Object {
		Join-Path $moduleInstallDir -ChildPath $_ | Get-ChildItem -Recurse | Get-FileHash
	}
}
